@@ -29,9 +29,9 @@ def start(input_str, application='', quiet=True):
 			run('open', '-a', application, input_str)
 	elif sys.platform == 'win32':
 		if application == '':
-			run('start', '', input_str)
+			run('cmd', '/c', 'start', input_str)
 		else:
-			run('start', '', application, input_str)
+			run('cmd', '/c', 'start', application, input_str)
 	else:
 		if application == '':
 			application = distutils.spawn.find_executable("xdg-open") # default to system installation of xdg-open
